#[repr(u8)]pub enum NswS1 {
NSW_S1_0 = 0,
NSW_S1_1 = 1,
}Variants
NSW_S1_0 = 0
The non-secure supervisor write access is disabled for the first slave.
NSW_S1_1 = 1
The non-secure supervisor write access is enabled for the first slave
Implementations