#[repr(u8)]pub enum NuwS1 {
NUW_S1_0 = 0,
NUW_S1_1 = 1,
}Variants
NUW_S1_0 = 0
The non-secure user write access is disabled for the first slave.
NUW_S1_1 = 1
The non-secure user write access is enabled for the first slave.
Implementations