#[repr(u8)]pub enum SsrS2 {
SSR_S2_0 = 0,
SSR_S2_1 = 1,
}Variants
SSR_S2_0 = 0
The secure supervisor read access is disabled for the second slave.
SSR_S2_1 = 1
The secure supervisor read access is enabled for the second slave.
Implementations