#[repr(u8)]pub enum SurS2 {
SUR_S2_0 = 0,
SUR_S2_1 = 1,
}Variants
SUR_S2_0 = 0
The secure user read access is disabled for the second slave.
SUR_S2_1 = 1
The secure user read access is enabled for the second slave.
Implementations